@@ -4,7 +4,35 @@
     assignInMyNamespace("guide_none", .ggplot2$guide_none)
   }
 }
+.hasUnits <- FALSE
+.rcppVersion <- utils::packageVersion("Rcpp")
+.PreciseSumsVersion <- utils::packageVersion("PreciseSums")
+.dparserVersion <- utils::packageVersion("dparser")
+.checkmateVersion <- utils::packageVersion("checkmate")
 .onLoad <- function(libname, pkgname) { ## nocov start
+  if (!identical(.rcppVersion, utils::packageVersion("Rcpp"))) {
+    stop("RxODE compiled with Rcpp '", as.character(.rcppVersion),
+         "' but Rcpp '", as.character(utils::packageVersion("Rcpp")), "' is loaded\nRecompile RxODE with the new version of Rcpp",
+         call.=FALSE)
+  }
+  if (!identical(.dparserVersion, utils::packageVersion("dparser"))) {
+    stop("RxODE compiled with dparser '", as.character(.dparserVersion),
+         "' but dparser '", as.character(utils::packageVersion("dparser")),
+         "' is loaded\nRecompile RxODE with the this version of dparser",
+         call.=FALSE)
+  }
+  if (!identical(.checkmateVersion, utils::packageVersion("checkmate"))) {
+    stop("RxODE compiled with checkmate '", as.character(.checkmateVersion),
+         "' but checkmate '", as.character(utils::packageVersion("checkmate")),
+         "' is loaded\nRecompile RxODE with the this version of checkmate",
+         call.=FALSE)
+  }
+  if (!identical(.PreciseSumsVersion, utils::packageVersion("PreciseSums"))) {
+    stop("RxODE compiled with PreciseSums '", as.character(.PreciseSumsVersion),
+         "' but PreciseSums '", as.character(utils::packageVersion("PreciseSums")),
+         "' is loaded\nRecompile RxODE with the this version of PreciseSums",
+         call.=FALSE)
+  }
   if (requireNamespace("pillar", quietly = TRUE)) {
     .s3register("pillar::type_sum", "rxEvid")
     .s3register("pillar::type_sum", "rxRateDur")
@@ -22,6 +50,22 @@
   if (requireNamespace("data.table", quietly = TRUE)) {
     .s3register("data.table::as.data.table", "rxEt")
   }
+  if (requireNamespace("units", quietly=TRUE)) {
+    .s3register("units::set_units", "rxEt")
+    .s3register("units::set_units", "rxRateDur")
+    .s3register("units::drop_units", "rxEt")
+    .s3register("units::drop_units", "rxSolve")
+    .s3register("units::units<-","rxEvid")
+    assignInMyNamespace(".hasUnits", TRUE)
+    .units <- loadNamespace("units")
+    assignInMyNamespace("type_sum.units", .units$type_sum.units)
+    assignInMyNamespace("format_type_sum.type_sum_units", .units$format_type_sum.type_sum_units)
+    assignInMyNamespace("pillar_shaft.units", .units$pillar_shaft.units)
+    assignInMyNamespace("type_sum.mixed_units", .units$type_sum.mixed_units)
+    assignInMyNamespace("pillar_shaft.mixed_units", .units$pillar_shaft.mixed_units)
+  } else {
+    assignInMyNamespace(".hasUnits", FALSE)
+  }
   backports::import(pkgname)
   ## Setup RxODE.prefer.tbl
   .Call(`_RxODE_setRstudio`, Sys.getenv("RSTUDIO") == "1")
